==> javacord-api-3.2.0.jar: META-INF/versions/9/module-info.java <==
module org.javacord.api {
    /* transitive */ requires java.desktop;

    exports org.javacord.api;
    exports org.javacord.api.event.user;
    exports org.javacord.api.event.connection;
    exports org.javacord.api.event.audio;
    exports org.javacord.api.event;
    exports org.javacord.api.event.channel;
    exports org.javacord.api.event.channel.group;
    exports org.javacord.api.event.channel.user;
    exports org.javacord.api.event.channel.server;
    exports org.javacord.api.event.channel.server.text;
    exports org.javacord.api.event.channel.server.invite;
    exports org.javacord.api.event.channel.server.voice;
    exports org.javacord.api.event.message;
    exports org.javacord.api.event.message.reaction;
    exports org.javacord.api.event.server;
    exports org.javacord.api.event.server.role;
    exports org.javacord.api.event.server.emoji;
    exports org.javacord.api.event.server.member;
    exports org.javacord.api.util;
    exports org.javacord.api.util.logging;
    exports org.javacord.api.util.event;
    exports org.javacord.api.util.concurrent;
    exports org.javacord.api.util.rest;
    exports org.javacord.api.util.auth;
    exports org.javacord.api.util.exception;
    exports org.javacord.api.util.ratelimit;
    exports org.javacord.api.util.cache;
    exports org.javacord.api.audio;
    exports org.javacord.api.exception;
    exports org.javacord.api.listener.webhook;
    exports org.javacord.api.listener;
    exports org.javacord.api.listener.user;
    exports org.javacord.api.listener.connection;
    exports org.javacord.api.listener.audio;
    exports org.javacord.api.listener.channel.group;
    exports org.javacord.api.listener.channel.user;
    exports org.javacord.api.listener.channel;
    exports org.javacord.api.listener.channel.server;
    exports org.javacord.api.listener.channel.server.text;
    exports org.javacord.api.listener.channel.server.invite;
    exports org.javacord.api.listener.channel.server.voice;
    exports org.javacord.api.listener.message.reaction;
    exports org.javacord.api.listener.message;
    exports org.javacord.api.listener.server;
    exports org.javacord.api.listener.server.role;
    exports org.javacord.api.listener.server.emoji;
    exports org.javacord.api.listener.server.member;
    exports org.javacord.api.entity.webhook;
    exports org.javacord.api.entity.user;
    exports org.javacord.api.entity.intent;
    exports org.javacord.api.entity.emoji;
    exports org.javacord.api.entity;
    exports org.javacord.api.entity.activity;
    exports org.javacord.api.entity.channel;
    exports org.javacord.api.entity.message;
    exports org.javacord.api.entity.message.embed;
    exports org.javacord.api.entity.message.mention;
    exports org.javacord.api.entity.auditlog;
    exports org.javacord.api.entity.server;
    exports org.javacord.api.entity.server.invite;
    exports org.javacord.api.entity.permission;
    exports org.javacord.api.util.logging.internal to org.javacord.core;
    exports org.javacord.api.util.internal to org.javacord.core;
    exports org.javacord.api.audio.internal to org.javacord.core;
    exports org.javacord.api.internal to org.javacord.core;
    exports org.javacord.api.entity.webhook.internal to org.javacord.core;
    exports org.javacord.api.entity.emoji.internal to org.javacord.core;
    exports org.javacord.api.entity.channel.internal to org.javacord.core;
    exports org.javacord.api.entity.message.embed.internal to org.javacord.core;
    exports org.javacord.api.entity.message.mention.internal to org.javacord.core;
    exports org.javacord.api.entity.message.internal to org.javacord.core;
    exports org.javacord.api.entity.server.invite.internal to org.javacord.core;
    exports org.javacord.api.entity.server.internal to org.javacord.core;
    exports org.javacord.api.entity.permission.internal to org.javacord.core;

}

==> javacord-api-3.5.0.jar: META-INF/versions/9/module-info.java <==
module org.javacord.api {
    /* transitive */ requires java.desktop;

    exports org.javacord.api.entity;
    exports org.javacord.api.entity.permission;
    exports org.javacord.api.entity.auditlog;
    exports org.javacord.api.entity.sticker;
    exports org.javacord.api.entity.intent;
    exports org.javacord.api.entity.activity;
    exports org.javacord.api.entity.webhook;
    exports org.javacord.api.entity.user;
    exports org.javacord.api.entity.channel;
    exports org.javacord.api.entity.emoji;
    exports org.javacord.api.entity.message;
    exports org.javacord.api.entity.message.component;
    exports org.javacord.api.entity.message.mention;
    exports org.javacord.api.entity.message.embed;
    exports org.javacord.api.entity.server;
    exports org.javacord.api.entity.server.invite;
    exports org.javacord.api;
    exports org.javacord.api.util.concurrent;
    exports org.javacord.api.util.auth;
    exports org.javacord.api.util;
    exports org.javacord.api.util.ratelimit;
    exports org.javacord.api.util.exception;
    exports org.javacord.api.util.rest;
    exports org.javacord.api.util.logging;
    exports org.javacord.api.util.cache;
    exports org.javacord.api.util.event;
    exports org.javacord.api.exception;
    exports org.javacord.api.audio;
    exports org.javacord.api.event.user;
    exports org.javacord.api.event.audio;
    exports org.javacord.api.event.connection;
    exports org.javacord.api.event.channel;
    exports org.javacord.api.event.channel.user;
    exports org.javacord.api.event.channel.server;
    exports org.javacord.api.event.channel.server.text;
    exports org.javacord.api.event.channel.server.invite;
    exports org.javacord.api.event.channel.server.voice;
    exports org.javacord.api.event.channel.thread;
    exports org.javacord.api.event;
    exports org.javacord.api.event.interaction;
    exports org.javacord.api.event.message;
    exports org.javacord.api.event.message.reaction;
    exports org.javacord.api.event.server;
    exports org.javacord.api.event.server.sticker;
    exports org.javacord.api.event.server.role;
    exports org.javacord.api.event.server.emoji;
    exports org.javacord.api.event.server.member;
    exports org.javacord.api.listener;
    exports org.javacord.api.listener.webhook;
    exports org.javacord.api.listener.user;
    exports org.javacord.api.listener.audio;
    exports org.javacord.api.listener.connection;
    exports org.javacord.api.listener.channel.user;
    exports org.javacord.api.listener.channel;
    exports org.javacord.api.listener.channel.server;
    exports org.javacord.api.listener.channel.server.text;
    exports org.javacord.api.listener.channel.server.invite;
    exports org.javacord.api.listener.channel.server.forum;
    exports org.javacord.api.listener.channel.server.voice;
    exports org.javacord.api.listener.channel.server.thread;
    exports org.javacord.api.listener.interaction;
    exports org.javacord.api.listener.message;
    exports org.javacord.api.listener.message.reaction;
    exports org.javacord.api.listener.server;
    exports org.javacord.api.listener.server.sticker;
    exports org.javacord.api.listener.server.role;
    exports org.javacord.api.listener.server.emoji;
    exports org.javacord.api.listener.server.member;
    exports org.javacord.api.interaction;
    exports org.javacord.api.interaction.callback;
    exports org.javacord.api.entity.permission.internal to org.javacord.core;
    exports org.javacord.api.entity.sticker.internal to org.javacord.core;
    exports org.javacord.api.entity.webhook.internal to org.javacord.core;
    exports org.javacord.api.entity.channel.internal to org.javacord.core;
    exports org.javacord.api.entity.emoji.internal to org.javacord.core;
    exports org.javacord.api.entity.message.component.internal to org.javacord.core;
    exports org.javacord.api.entity.message.internal to org.javacord.core;
    exports org.javacord.api.entity.message.mention.internal to org.javacord.core;
    exports org.javacord.api.entity.message.embed.internal to org.javacord.core;
    exports org.javacord.api.entity.server.internal to org.javacord.core;
    exports org.javacord.api.entity.server.invite.internal to org.javacord.core;
    exports org.javacord.api.internal to org.javacord.core;
    exports org.javacord.api.util.internal to org.javacord.core;
    exports org.javacord.api.util.logging.internal to org.javacord.core;
    exports org.javacord.api.audio.internal to org.javacord.core;
    exports org.javacord.api.interaction.internal to org.javacord.core;

}
